//radiopc.c     //pc side radio

#include <mega644.h>
#include <rf.h>
#include <stdio.h> 
#include <string.h>
                    
#define TRUE 	1
#define FALSE 	0    
#define TIMEOUT 9      //time to loop back for next photo 
  
unsigned char timer;

void initialize(void);    
void initUART(void); 
void fetch(void);

interrupt [TIM1_COMPA] void timer1_comp(void)  {
        if(timer>0) --timer;
}

void initialize(void){
        initSPI();              //set up SPI for MCU
        initTransceiver();      //set up transceiver 
        initUART();  
        
        DDRD.2 = 1;     //led indicator
        PORTD.2 = 0; 
        
        TCCR1A = 0b00000000;  //Clear timer on compare match, coupled with TCCR0B settings
        TCCR1B = 0b00001101;  //Clear timer on compare match, Timer set up to f/1024
        OCR1AH = 0x7A;           //produce timer for 4s, need to count to 31250=0x7A12, 9 of this yields 36s
        OCR1AL = 0x12;
        TIMSK1 = 0b00000010;    //interrupt enable for compare match A

        #asm
        sei     //enable interrupts     
        #endasm
}                  

void initUART(void){
        UBRR0L = 12; // baud rate: 38400 for 8 MHz
        UCSR0B = (1<<4)|(1<<3); //enable receiver and transmit
        UCSR0C = (1<<7)|(1<<3)|(1<<2)|(1<<1);    //register select; 2 stop bits; 8 bits
}      

void fetch(void){      
        timer = TIMEOUT;        //reset timer   
        rfSetTxMode(); 
        txDataLength = 1; 
        txFrame[0] = ACT;  
        rfSendFrame();
                                                 
        rfSetRxMode();           //transceiver set to receive   
       
        clearIRQ();
      
        while(timer>0){
                if(rfRxListenNoWait()==1){
                        PORTD.2 = ~PORTD.2;  
                        rfRetrieveFrame();   //retrieve frame   
                }
        }     
}

void main(void){
        initialize(); 
        delay_ms(5000); //initial one-time delay   
        while(1){
                if(timer==0)fetch();
        }       
}  